==> portmanager-0.3.4.tar.gz: portmanager-0.3.4/libMGPM/src/libMGPM.h <==
/*
	Copyright (C) 2005  Michael C. Shultz

	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions
	are met:

	1. Redistributions of source code must retain the above copyright
	   notice, this list of conditions and the following disclaimer.
	2. Redistributions in binary form must reproduce the above copyright
	   notice, this list of conditions and the following disclaimer in the
	   documentation and/or other materials provided with the distribution.

	THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
	IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
	OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
	IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
	NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
	DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
	THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
	THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

	Michael C. Shultz
	ringworm01@gmail.com
	Box 3238 Landers, CA 92285
*/

/*
bsd.port.mk info

PORT_DBDIR	/var/db/ports	Where port configuration options are recorded

PKG_DBDIR       /var/db/pkg	Where package installation is recorded

WRKDIRPREFIX      		The place to root the temporary working directory

*/

#ifndef __LIBPMGR_H__
#define __LIBPMGR_H__	1

#include	<externVars.h>
#include	<libMG.h>

#define	MULTI				0
#define	SINGLE				1

#define	DEBUG_PMGRrDbCreate		0
#define	DEBUG_PMGRrMakeDescribe		0
#define	DEBUG_PMGRrReadConfigure	0
#define	DEBUG_PMGRrStatus		0
#define	DEBUG_PMGRrMissingDependencies	0

/****************************************/
/* SHAREDIR defined in bsd.port.mk	*/ 
/* PKGDBDIR defined in bsd.port.mk	*/
/* data_DATA see automake manual	*/
/****************************************/

/*
 * The following are defined in <externVars.h>
 *
 * BINDIR
 * ETCDIR
 * PKGDBDIR
 * PORTSDIR
 * SHAREDIR
 * TEMPDIR
 *
 */

#define	COMMANDLINE_DB		"/commandLine.db"
#define	CONFIGURE_DB		"/configure.db"
#define	HELPFILE		"/help.txt"
#define	IGNORE_DB		"/ignore.db"
#define	PORTS_CACHE_DB		"/ports_cache.db"
#define	PORTS_AVAILABLE_DB	"/ports_available.db"
#define	PORTS_AVAILABLE_DEPENDENCIES_DB	"/ports_available_dependencies.db"
#define	PORTS_INSTALLED_DB	"/ports_installed.db"
#define	PORTS_OLD_DB		"/ports_old.db"
#define	PORT_DEPENDENCIES_DB	"/ports_dependencies.db"
#define	STRIKES_DB		"/3strikes.db"
#define CONFIGURE_CONF		"/pm-020.conf"

typedef	struct classPort classPort;

typedef struct
{
	/*
	 * default flags
	 */
	int	autoConflicts;			/* if 1 then conflicts Y/N default is Y */
	int	autoMoved;			/* if 1 then remove moved ports is Y */
	int	backUp;				/* if 1 then make packages for updatyed ports */
	int	buildDependsAreLeaves;		/* 1 = treat build depends as if they don't exist in availableDependencies.db */
	int	forced;				/* 1 = forced updates 0 = normal */
	int	interactive;			/* 0 = non, 1 = interactive */
	int	log;				/* if 1 then enable logging */
	int	objIdx;
	int	optionsChanged;			/* set by MGPMrUpdate for example to indicate a ports's options just changed */ 
	int	pmMode;				/* singlePort Upgrade = 1 multiple upgrade = 0 */
	int	resume;				/* 0=normal 1=don't create databases*/
	int	verbose;
	
	/*
	 * misc
	 */
	char*	helpFile;
	char*	configConfFileName;

	/*
	 * data base structures/file names/fieldnames
	 */

	char*	availableDependenciesDbFileName;
	char*	fieldAvailableDependenciesDbPortDir;
	char*	fieldAvailableDependenciesDbPortName;
	char*	fieldAvailableDependenciesDbDependencyDir;
	char*	fieldAvailableDependenciesDbDependencyName;
	char*	fieldAvailableDependenciesDbDependType;

	char*	availablePortsDbFileName;
	char*	fieldAvailablePortsDbPortName;
	char*	fieldAvailablePortsDbPortDir;
	char*	fieldAvailablePortsDbFlag;

	char*	cacheDbFileName;
	char*	fieldCacheDbPortDir;
	char*	fieldCacheDbAvailablePortName;
	char*	fieldCacheDbMakeFileSize;
	char*	fieldCacheDbMakeFileTime;

	char*	commandLineDbFileName;
	char*	fieldCommandLineDbKey;
	char*	fieldCommandLineDbValue;

	char*	configDbFileName;
	char*	fieldConfigDbKey;
	char*	fieldConfigDbValue;

	char*	dependencyPortsDbFileName;
	char*	fieldDependencyDbPortDir;
	char*	fieldDependencyDbPortName;
	char*	fieldDependencyDbDependencyPortDir;
	char*	fieldDependencyDbDependencyPortName;

	char*	ignoreDbFileName;
	char*	fieldignoreDbPortDir;
	char*	fieldIgnoreDbReason;

	char*	installedPortsDbFileName;
	char*	fieldInstalledPortsDbPortName;
	char*	fieldInstalledPortsDbPortDir;
	char*	fieldInstalledPortsDbFlag;

	char*	oldPortsDbFileName;
	char*	fieldOldPortsDbOldPortDir;
	char*	fieldOldPortsDbOldPortName;
	char*	fieldOldPortsDbReason;
	char*	fieldOldPortsDbNewPortName;
	char*	fieldOldPortsDbNewPortDir;
	
	char*	strikesDbFileName;
	char*	fieldStrikesDbPortDir;
	char*	fieldStrikesIDX;

	classDb*	availableDependenciesDb;
	classDb*	availablePortsDb;
	classDb*	cacheDb;
	classDb*	commandLineDb;
	classDb*	configDb;
	classDb*	dependencyPortsDb;
	classDb*	ignoreDb;
	classDb*	installedPortsDb;
	classDb*	oldPortsDb;
	classDb*	strikesDb;
	classDir*	dir;
	classPort*	portTree;

} structProperty;

int	MGPMrBestOldPort( structProperty* property, char* oldPortDir, char* oldPortName );
int	MGPMrCleanUp( structProperty* property );
int	MGPMrCommandLine(  int argc, char** argv );
int	MGPMrController( structProperty* property, char* path );
int	MGPMrCreateAllUpdateStatusDb( structProperty* property );
int	MGPMrCreateInstalledDb( structProperty* property );
int	MGPMrInitialize( structProperty* property );
int	MGPMrMakeDescribe( structProperty* property, char* installedPortDir, char* available );
int	MGPMrMissingDependencies( structProperty* property );
int	MGPMrReadConfigure( structProperty* property );
int	MGPMrShowLeaves( structProperty* property );
int	MGPMrShowLeavesDelete( structProperty* property );
int	MGPMrSinglePortCreateStatusDb( structProperty* property, char* path );
int	MGPMrSinglePortStatus( structProperty* property );
int	MGPMrStatus( structProperty* property );
int	MGPMrUpdate(structProperty* property, char* oldPortDir, char* oldPortName );

#endif

==> portmanager-0.4.1.tar.gz: portmanager-0.4.1/libMGPM/src/libMGPM.h <==
/*
	Copyright (C) 2005  Michael C. Shultz

	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions
	are met:

	1. Redistributions of source code must retain the above copyright
	   notice, this list of conditions and the following disclaimer.
	2. Redistributions in binary form must reproduce the above copyright
	   notice, this list of conditions and the following disclaimer in the
	   documentation and/or other materials provided with the distribution.

	THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
	IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
	OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
	IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
	NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
	DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
	THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
	THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

	Michael C. Shultz
	ringworm01@gmail.com
	Box 3238 Landers, CA 92285
*/

/*
bsd.port.mk info

PORT_DBDIR	/var/db/ports	Where port configuration options are recorded

PKG_DBDIR       /var/db/pkg	Where package installation is recorded

WRKDIRPREFIX      		The place to root the temporary working directory

make -V PKGFILE
/usr/ports/packages/All/amavisd-new-2.3.3,1.tbz

*/

#ifndef __LIBPMGR_H__
#define __LIBPMGR_H__	1

#include	<externVars.h>
#include	<libMG.h>

#define	CRASH	100
#define	MULTI	0
#define	OK	0
#define	SINGLE	1
#define	SKIP	10

#define	DEBUG_PMGRrDbCreate		0
#define	DEBUG_PMGRrMakeDescribe		0
#define	DEBUG_PMGRrReadConfigure	0
#define	DEBUG_PMGRrStatus		0
#define	DEBUG_PMGRrMissingDependencies	0

/****************************************/
/* SHAREDIR defined in bsd.port.mk	*/ 
/* PKGDBDIR defined in bsd.port.mk	*/
/* data_DATA see automake manual	*/
/****************************************/

/*
 * The following are defined in <externVars.h>
 *
 * BINDIR
 * ETCDIR
 * PKGDBDIR
 * PORTSDIR
 * SHAREDIR
 * TEMPDIR
 *
 */

#define	COMMANDLINE_DB		"/commandLine.db"
#define	CONFIGURE_DB		"/configure.db"
#define	HELPFILE		"/help.txt"
#define	IGNORE_DB		"/ignore.db"
#define	PORTS_CACHE_DB		"/ports_cache.db"
#define	PORTS_AVAILABLE_DB	"/ports_available.db"
#define	PORTS_AVAILABLE_DEPENDENCIES_DB	"/ports_available_dependencies.db"
#define	PORTS_INSTALLED_DB	"/ports_installed.db"
#define	PORTS_OLD_DB		"/ports_old.db"
#define	PORT_DEPENDENCIES_DB	"/ports_dependencies.db"
#define	STRIKES_DB		"/3strikes.db"
#define CONFIGURE_CONF		"/pm-020.conf"

typedef	struct classLog classLog;

typedef struct
{
	char*	CURDIR;
	char*	afterOptionsFileSize;
	char*	afterOptionsFileTime;
	char*	batchCheck;
	char*	beforeOptionsFileSize;
	char*	beforeOptionsFileTime;
	char*	buffer;
	char*	command;
	char*	commandRestart;
	char*	installedPortName;
	char*	newPortDir;
	char*	newPortName;
	char*	oldPortDir;
	char*	oldPortName;
	char*	options;
	char*	optionsCheck;
	char*	optionsDir;
	char*	startPortCmd;
	char*	startPortDir;
	char*	stopPortCmd;
	char*	stopPortDir;
	char*	workDir;
	char*	workFullPath;
	char*	xtermTitle;
	char**	environment;
	int	bufferSize;
	int	optionsBufferSize;
} structLocalProperty;

typedef struct
{
	char**	argp;
	/*
	 * default flags
	 */
	int	autoConflicts;			/* if 1 then conflicts Y/N default is Y */
	int	autoMoved;			/* if 1 then remove moved ports is Y */
	int	backUp;				/* if 1 then make packages for updatyed ports */
	int	bsdPortMkPatched;		/* 1 = bsd.port.mk is in patched state */
	int	bsdPortMkPatchedBlock;		/* 1 = bsd.port.mk can't be patch so quit trying */
	int	buildDependsAreLeaves;		/* 1 = treat build depends as if they don't exist in availableDependencies.db */
	int	forced;				/* 1 = forced updates 0 = normal */
	int	interactive;			/* 0 = non, 1 = interactive */
	int	log;				/* if 1 then enable logging */
	int	objIdx;
	int	optionsChanged;			/* set by MGPMrUpdate for example to indicate a ports's options just changed */ 
	int	pmMode;				/* singlePort Upgrade = 1 multiple upgrade = 0 */
	int	pristine;			/* 1 = run in pristine mode */
	int	resume;				/* 0=normal 1=don't create databases*/
	int	timeout;			/* default timeout in seconds */
	int	verbose;
	
	FILE*	STDIN;
	/*
	 * misc
	 */
	char*	configConfFileName;
	char*	helpFile;
	int	timeOut;			/* see MGPMrGetPortName.c */
	int	NoPkgtools;			/* 1 = pkgtools.conf or ruby not installed */
	
	/*
	 * data base structures/file names/fieldnames
	 */

	char*	availableDependenciesDbFileName;
	char*	fieldAvailableDependenciesDbPortDir;
	char*	fieldAvailableDependenciesDbPortName;
	char*	fieldAvailableDependenciesDbDependencyDir;
	char*	fieldAvailableDependenciesDbDependencyName;
	char*	fieldAvailableDependenciesDbDependType;

	char*	availablePortsDbFileName;
	char*	fieldAvailablePortsDbPortName;
	char*	fieldAvailablePortsDbPortDir;
	char*	fieldAvailablePortsDbFlag;

	char*	cacheDbFileName;
	char*	fieldCacheDbPortDir;
	char*	fieldCacheDbAvailablePortName;
	char*	fieldCacheDbMakeFileSize;
	char*	fieldCacheDbMakeFileTime;

	char*	commandLineDbFileName;
	char*	fieldCommandLineDbKey;
	char*	fieldCommandLineDbValue;

	char*	configDbFileName;
	char*	fieldConfigDbKey;
	char*	fieldConfigDbValue;

	char*	dependencyPortsDbFileName;
	char*	fieldDependencyDbPortDir;
	char*	fieldDependencyDbPortName;
	char*	fieldDependencyDbDependencyPortDir;
	char*	fieldDependencyDbDependencyPortName;

	char*	ignoreDbFileName;
	char*	fieldignoreDbPortDir;
	char*	fieldIgnoreDbReason;

	char*	installedPortsDbFileName;
	char*	fieldInstalledPortsDbPortName;
	char*	fieldInstalledPortsDbPortDir;
	char*	fieldInstalledPortsDbFlag;

	char*	oldPortsDbFileName;
	char*	fieldOldPortsDbOldPortDir;
	char*	fieldOldPortsDbOldPortName;
	char*	fieldOldPortsDbReason;
	char*	fieldOldPortsDbNewPortName;
	char*	fieldOldPortsDbNewPortDir;
	
	char*	strikesDbFileName;
	char*	fieldStrikesDbPortDir;
	char*	fieldStrikesIDX;

	classDb*	availableDependenciesDb;
	classDb*	availablePortsDb;
	classDb*	cacheDb;
	classDb*	commandLineDb;
	classDb*	configDb;
	classDb*	dependencyPortsDb;
	classDb*	ignoreDb;
	classDb*	installedPortsDb;
	classDb*	oldPortsDb;
	classDb*	strikesDb;
	classDir*	dir;
	classLog*	logFile;

} structProperty;

structProperty*	globalProperty;

classLog*	MGPMlogCreate( structProperty* property );
int		MGPMlogAdd( structProperty* property, char* victemName, char* victemDir, char* crime, char* suspectName, char* suspectDir );
int		MGPMlogDestroy( structProperty* property );
int		MGPMrBestOldPort( structProperty* property, char* oldPortDir, char* oldPortName );
int		MGPMrCleanUp( structProperty* property );
int		MGPMrCommandLine( int argc, char** argv, char** argp );
int		MGPMrController( structProperty* property, char* path, char** argv );
int		MGPMrCreateAllUpdateStatusDb( structProperty* property );
int		MGPMrCreateInstalledDb( structProperty* property );
int		MGPMrDependencyParse( structProperty* property, char* buffer, char* availablePortName, char* availablePortDir, char* dependType, int* counterPtr );
int		MGPMrGetPortName( structProperty* property, char* portDir, char* portName );
int		MGPMrInitialize( structProperty* property );
int		MGPMrIsRunDependency( structProperty* property, char* portDir, char* dependencyDir );
int		MGPMrMakeDescribe( structProperty* property, char* installedPortDir, char* available );
int		MGPMrMissingDependencies( structProperty* property );
int		MGPMrPackageDepends( structProperty* property , char* path );
int		MGPMrParse( structProperty* property, char* availablePortName, char* availablePortDir, char* dependType, char* buffer, int* counterPtr );
int		MGPMrPortBrokeCheck( structProperty* property, char* options, char* oldPortDir, char* oldPortName, char* brokeCheckType );
int		MGPMrReadConfigure( structProperty* property, char* newPortDir );
int		MGPMrShowLeaves( structProperty* property );
int		MGPMrShowLeavesDelete( structProperty* property );
int		MGPMrSinglePortCreateStatusDb( structProperty* property, char* path );
int		MGPMrStatus( structProperty* property );
int		MGPMrUpdate(structProperty* property, char* oldPortDir, char* oldPortName );
int 		MGPMrBsdPortMkRevertPatch( structProperty* property );
void		MGPMrCatchSignal(int signalId );	/* located in MGPMrCommandLine.c */
void		MGPMrTimer( int signalId );		/* located in MGPMrCommandLine.c */

#endif
